# Wrapper for MOSAiCS
# Written by Dongjun Chung, Sep. 15, 2011

#!/usr/bin/env perl;
use warnings;
use strict;
use File::Temp qw/tempfile/;
use File::Temp qw/tempdir/;
use File::Basename;

# parse command arguments

die "Usage: perl mosaics_wrapper.pl [chip_path] [control_path] [chip_file_format] [control_file_format] [peak_path] [peak_file_format] [analysis_type] [report_summary_path] [report_gof_path] [report_exploratory_path] [fdr_level] [frag_len] [bin_size] [capping] [signal_model] [d] [maxgap] [minsize] [thres] [n_core]" unless @ARGV == 20;

my ( $chip_path, $control_path, $chip_file_format, $control_file_format, $peak_path, $peak_file_format, $analysis_type, $report_summary_path, $report_gof_path, $report_exploratory_path, $fdr_level, $frag_len, $bin_size, $capping, $signal_model, $d, $maxgap, $minsize, $thres, $n_core ) = @ARGV;

# parse options: analysis type

if ( $analysis_type ne "IO" ) {
	print "Only 'IO' is supported for analysis type!\n";
	exit 1;	
}

# parse options: ChIP, control, peak

my ($chip_filename, $chip_dir) = fileparse($chip_path);
my ($control_filename, $control_dir) = fileparse($control_path);
my ($peak_filename, $peak_dir) = fileparse($peak_path);

# parse options: report summary

my $report_summary = "FALSE";
my $summary_dir = "NULL";
my $summary_filename = "NULL";
if ( $report_summary_path ne "None" ) {
	$report_summary = "TRUE";
	($summary_filename, $summary_dir) = fileparse($report_summary_path);
}

# parse options: report GOF

my $report_gof = "FALSE";
my $gof_dir = "NULL";
my $gof_filename = "NULL";
if ( $report_gof_path ne "None" ) {
	$report_gof = "TRUE";
	($gof_filename, $gof_dir) = fileparse($report_gof_path);
}

# parse options: report exploratory analysis

my $report_exploratory = "FALSE";
my $exploratory_dir = "NULL";
my $exploratory_filename = "NULL";
if ( $report_exploratory_path ne "None" ) {
	$report_exploratory = "TRUE";
	($exploratory_filename, $exploratory_dir) = fileparse($report_exploratory_path);
}

# write a R scrip to run

my $tempdir_bin = tempdir();

my $cmd = qq|
	suppressPackageStartupMessages(library(mosaics))
	try( suppressPackageStartupMessages(library(rparallel)), silent=TRUE )
	
	mosaicsRunAll( 
		chipDir="$chip_dir", 
		chipFileName="$chip_filename", 
		chipFileFormat="$chip_file_format", 
		controlDir="$control_dir",
		controlFileName="$control_filename", 
		controlFileFormat="$control_file_format",
		binfileDir="$tempdir_bin",
		peakDir="$peak_dir",
		peakFileName="$peak_filename",
		peakFileFormat="$peak_file_format",
		reportSummary=$report_summary, 
		summaryDir="$summary_dir",
		summaryFileName="$summary_filename",
		reportExploratory=$report_exploratory,
		exploratoryDir="$exploratory_dir",
		exploratoryFileName="$exploratory_filename",
		reportGOF=$report_gof,
		gofDir="$gof_dir",
		gofFileName="$gof_filename",
		FDR=$fdr_level, 
		fragLen=$frag_len, 
		binSize=$bin_size, 
		capping=$capping, 
		analysisType="$analysis_type", 
		d=$d, 
		signalModel="$signal_model", 
		maxgap=$maxgap, 
		minsize=$minsize, 
		thres=$thres, 
		nCore=$n_core )
	
	q()
	|;

# run R

open( FT, "| R --slave --vanilla >& /dev/null" ) or die "Couldn't call R!\n";
print FT $cmd, "\n";
close FT or die "Couldn't finish R!\n";

exit;


